# 文献启明星（LightStar）- 科研调研智能体系统

## 项目简介

**文献启明星**是一款面向科研初学者的 AI 智能体系统，致力于帮助用户从模糊的研究意图出发，自动完成科研调研的核心流程，包括：主题拆解、文献检索、文献聚类、结构总结、代表文献推荐与调研报告生成。

用户仅需输入一句话，即可获得一份结构化的初步调研成果，用于选题、开题、综述写作或项目申报。本项目采用前后端分离架构，支持多端适配，为不同场景下的科研人员提供便捷服务。

## 最新功能更新

**户账户系统**：新增用户注册、登录和个人资料管理功能
**AI聊天助手**：引入智能对话功能，辅助研究过程中的问题解答
**研究报告生成**：支持自动生成格式化的研究报告，包括章节标题和详细内容
**论文检索与显示**：优化了论文结果显示，支持查看完整摘要和原文链接
**HTML导出**：支持将研究报告以HTML格式导出，方便用户保存和分享
**UI交互优化**：研究助手界面全新设计，分离显示论文列表和研究报告
**多语言支持**：支持英文研究报告生成
**实时进度反馈**：在研究过程中提供实时的进度更新和关键词提取

## 技术架构

### 后端 (Backend)
- **框架**: FastAPI
- **语言**: Python 3.8+
- **数据库**: SQLite (通过SQLAlchemy ORM)
- **认证**: JWT令牌认证
- **核心依赖**:
  - arxiv API (文献检索)
  - sentence-transformers (文本向量化)
  - scikit-learn (聚类分析)
  - Deepseek API (报告生成和AI聊天)
  - Pydantic (数据验证)
  - SQLAlchemy (数据库ORM)

### 前端 (Frontend)
- **框架**: Next.js 14
- **UI构建**: Tailwind CSS 3
- **状态管理**: React Hooks
- **认证**: 基于JWT的用户验证系统
- **特色功能**:
  - 响应式设计，适配不同设备
  - 多主题切换系统
  - 玻璃态UI设计 (Glassmorphism)
  - 模态框交互
  - 实时数据流处理 (Server-Sent Events)
  - 用户面板和个人资料管理

## 项目结构

```bash
lightstar/
├── backend/                    # FastAPI后端服务
│   ├── main.py                 # 主入口
│   ├── config.py               # 配置文件
│   ├── init_db.py              # 数据库初始化
│   ├── api/                    # API路由
│   ├── core/                   # 核心业务逻辑
│   │   ├── auth.py             # 认证系统
│   │   ├── models.py           # 数据模型
│   │   ├── database.py         # 数据库连接
│   │   ├── research.py         # 研究流程
│   │   ├── clustering.py       # 聚类算法
│   │   └── report.py           # 报告生成
│   └── utils/                  # 工具函数
│
├── lightstar-web/              # Next.js前端应用
│   ├── src/
│   │   ├── app/                # 页面
│   │   │   ├── login/          # 登录页面
│   │   │   ├── register/       # 注册页面
│   │   │   ├── dashboard/      # 仪表盘页面
│   │   │   ├── profile/        # 个人资料页面
│   │   │   └── ai-chat/        # AI聊天页面
│   │   ├── components/         # UI组件
│   │   │   ├── ui/             # 基础UI组件
│   │   │   └── forms/          # 表单组件
│   │   └── lib/                # 工具函数
│   └── public/                 # 静态资源
│
└── README.md                   # 项目说明文档
```

## 环境配置

1. **克隆仓库**
```bash
git clone http://git.fmode.cn:3000/XMD/Lightstar.git
cd Lightstar
```

2. **配置环境变量**
复制环境变量模板并填写必要信息
```bash
cp .env.example .env
# 编辑.env文件，填写必要的API密钥
```

## 使用说明

### 后端服务启动

```bash
# 创建虚拟环境(可选)
python -m venv venv
source venv/bin/activate  # Linux/Mac
# 或
venv\Scripts\activate     # Windows

# 安装依赖
pip install -r requirements.txt

# 初始化数据库
cd backend
python init_db.py

# 启动后端服务
python main.py
```

后端服务将在 http://localhost:8000 启动

### 前端应用启动

```bash
cd lightstar-web
npm install
npm run dev
```

前端应用将在 http://localhost:3000 启动

## 功能详解

### 用户账户系统
1. **用户注册**: 创建新账户，提供用户名、邮箱和密码
2. **用户登录**: 安全登录系统，获取JWT令牌
3. **个人资料**: 查看和更新个人信息
4. **会话管理**: 自动刷新令牌，确保无缝体验

### 研究助手界面

研究助手提供了一站式调研流程，主要功能包括：

1. **研究主题输入**：用户只需输入自己感兴趣的研究主题
2. **关键词提取**：系统自动从研究主题中提取关键词
3. **研究方向生成**：基于关键词生成多个研究方向
4. **论文检索**：为每个研究方向自动检索相关论文
5. **研究报告生成**：为每个研究方向生成详细的研究报告
6. **报告导出**：支持将研究报告导出为HTML格式

### AI聊天助手
1. **智能对话**: 基于大型语言模型的对话系统
2. **研究相关问答**: 解答研究过程中的问题
3. **文献解析帮助**: 辅助理解复杂文献
4. **研究建议**: 提供研究方向和方法建议

### 界面交互

1. **论文模态框**：点击"查看相关论文"可打开论文列表模态框，显示论文标题、作者、年份、摘要等信息，支持点击论文标题查看原文
2. **报告模态框**：点击"查看研究报告"可打开报告模态框，显示完整研究报告，支持下载为HTML格式
3. **聊天界面**: 友好的聊天界面设计，支持代码高亮和降价格式

## 功能特点（功能持续拓展中）

- 用户身份验证和账户管理
- 智能AI聊天助手
- 智能研究主题解析
- 自动文献检索与分析
- 文献聚类与可视化
- 研究报告自动生成
- 多主题UI，提供舒适的视觉体验
- 响应式设计，支持各类设备
- HTML格式报告导出
- 实时进度反馈
- 文献原文链接直达

## 下一步计划

- [ ] 添加研究报告PDF导出功能
- [ ] 支持更多文献数据库的集成
- [ ] 增强文献分析功能，提供引用网络
- [ ] 历史研究项目保存与管理
- [ ] 团队协作功能
- [ ] 开发移动端应用
- [ ] 增加自定义研究报告模板
- [ ] 引入更多高级AI模型
- [ ] 添加主题图表可视化功能
- [ ] 支持批量导出文献元数据

## 贡献指南

1. Fork项目仓库
2. 创建功能分支 (`git checkout -b feature/amazing-feature`)
3. 提交更改 (`git commit -m 'Add some amazing feature'`)
4. 推送分支 (`git push origin feature/amazing-feature`)
5. 创建Pull Request

## 联系方式

项目负责人：[XMD] - [xumingdi2004@icloud.com]

---

## 目标用户

- 初入科研的硕士/博士研究生
- 缺乏调研经验的年轻教师或科研助理
- 对某一新领域感兴趣的项目开发人员
- 需要在多种设备上进行科研调研的研究人员

---

## 核心价值

| 用户痛点 | 文献启明星的解决方案 |
|----------|----------------------|
| 不会选题、不知从哪开始 | AI 拆解主题，提炼研究方向 |
| 不会查文献，效率低 | 自动调用开放数据库进行检索 |
| 无法判断文献质量 | 提供引用数、摘要、推荐标记 |
| 看完文献却写不出综述 | 聚类归纳 + 自动报告生成 |
| 对研究有疑问无人解答 | AI助手提供智能对话支持 |
| 时间紧、任务重、无从下手 | 一站式完成调研闭环 |
| 需要随时随地进行研究 | 多端适配，支持Web/移动/桌面 |

---

## 功能流程图

```text
用户注册/登录 → 个人资料设置
         ↓
用户输入研究意图
         ↓
AI 拆解关键词与子主题
         ↓
调用文献 API 自动检索（arXiv / Semantic Scholar）
         ↓
聚类文献主题，归纳关键词与研究路线
         ↓
推荐经典/综述文献（摘要 + 链接）
         ↓
输出结构化调研报告（含HTML导出功能）
         ↓
AI聊天助手辅助解答研究问题
```

## 界面预览

- 用户登录/注册界面：简洁明了的身份验证入口
- 个人资料页面：用户信息管理
- 研究助手界面：提供直观的研究主题输入和结果展示
- AI聊天界面：友好的对话式帮助系统
- 论文列表模态框：显示相关论文及其详细信息
- 研究报告模态框：格式化展示完整研究报告，支持HTML导出

## 错误处理

系统提供了完善的错误处理机制，包括：

- 连接失败重试
- 用户友好的错误提示
- 调试信息记录
- 数据缓存恢复
- 认证错误处理

## 许可证

本项目遵循 MIT 许可证
