import { NextRequest } from 'next/server';

export async function GET(request: NextRequest) {
  const searchParams = request.nextUrl.searchParams;
  const researchIntent = searchParams.get('research_intent');
  
  if (!researchIntent) {
    return new Response(
      JSON.stringify({ error: "研究主题不能为空" }), 
      { status: 400, headers: { 'Content-Type': 'application/json' }}
    );
  }
  
  // 确定后端API地址（优先使用环境变量）
  const apiBaseUrl = process.env.BACKEND_API_URL || 'http://localhost:8000';
  const apiUrl = `${apiBaseUrl}/api/research/enhanced-process-stream?research_intent=${encodeURIComponent(researchIntent)}`;
  
  try {
    // 使用代理模式而不是重定向
    const response = await fetch(apiUrl);
    
    // 如果后端不可用，返回一个明确的错误
    if (!response.ok) {
      if (response.status === 404) {
        return new Response(
          JSON.stringify({ error: "后端API不存在或未启动，请检查后端服务" }), 
          { status: 502, headers: { 'Content-Type': 'application/json' }}
        );
      }
      
      return new Response(
        JSON.stringify({ error: `后端API返回错误：${response.status} ${response.statusText}` }), 
        { status: 502, headers: { 'Content-Type': 'application/json' }}
      );
    }
    
    // 创建新的Response并使用ReadableStream转发数据
    return new Response(response.body, {
      headers: {
        'Content-Type': 'text/event-stream',
        'Cache-Control': 'no-cache',
        'Connection': 'keep-alive'
      }
    });
  } catch (error) {
    console.error('Error proxying SSE request:', error);
    return new Response(
      JSON.stringify({ error: "连接后端服务失败，请确保后端服务已启动" }), 
      { status: 500, headers: { 'Content-Type': 'application/json' }}
    );
  }
} 