import { GlassCard } from "@/components/ui/glass-card";
import { Button } from "@/components/ui/button";
import Link from "next/link";

export default function Dashboard() {
  return (
    <main className="relative flex min-h-[calc(100vh-64px)] flex-col items-center justify-center p-4 sm:p-8">
      <div className="container max-w-4xl mx-auto z-10">
        <div className="text-center mb-8">
          <h1 className="text-5xl md:text-6xl font-bold text-center text-transparent bg-clip-text bg-gradient-to-r from-white to-white/70 mb-3 drop-shadow-lg">
            控制中心
          </h1>
          <p className="text-xl text-center text-white/80 mb-2">
            智能科研助手平台
          </p>
          <div className="w-16 h-1 mx-auto bg-gradient-to-r from-[var(--theme-accent)] to-[var(--theme-highlight)] rounded-full"></div>
        </div>
        
        <div className="grid grid-cols-1 md:grid-cols-2 gap-6 mb-8">
          {/* 文献研究功能卡片 */}
          <GlassCard className="relative overflow-hidden group">
            <div className="absolute top-0 right-0 -mt-4 -mr-4 h-16 w-16 rounded-full bg-gradient-to-br from-[var(--theme-highlight)] to-[var(--theme-accent)] opacity-70 blur-xl group-hover:opacity-100 transition-opacity"></div>
            
            <h2 className="text-2xl font-bold text-white mb-3">文献研究</h2>
            <p className="text-white/80 mb-4">
              智能分析研究领域，生成研究方向报告，查找相关论文与文献。
            </p>
            <div className="flex space-x-3">
              <Link href="/" className="inline-block">
                <Button>开始研究</Button>
              </Link>
              <Button variant="outline">查看历史</Button>
            </div>
          </GlassCard>
          
          {/* AI聊天功能卡片 */}
          <GlassCard className="relative overflow-hidden group">
            <div className="absolute top-0 right-0 -mt-4 -mr-4 h-16 w-16 rounded-full bg-gradient-to-br from-[var(--theme-highlight)] to-[var(--theme-accent)] opacity-70 blur-xl group-hover:opacity-100 transition-opacity"></div>
            
            <h2 className="text-2xl font-bold text-white mb-3">AI 聊天</h2>
            <p className="text-white/80 mb-4">
              与智能助手交流，解答学术问题，获取研究建议和文献推荐。
            </p>
            <div className="flex space-x-3">
              <Link href="/ai-chat" className="inline-block">
                <Button>开始对话</Button>
              </Link>
              <Button variant="outline">查看历史</Button>
            </div>
          </GlassCard>
          
          {/* 论文分析功能卡片 */}
          <GlassCard className="relative overflow-hidden group">
            <div className="absolute top-0 right-0 -mt-4 -mr-4 h-16 w-16 rounded-full bg-gradient-to-br from-[var(--theme-highlight)] to-[var(--theme-accent)] opacity-70 blur-xl group-hover:opacity-100 transition-opacity"></div>
            
            <h2 className="text-2xl font-bold text-white mb-3">论文分析</h2>
            <p className="text-white/80 mb-4">
              上传论文PDF，自动提取关键信息，生成摘要和解读，获取相关文献推荐。
            </p>
            <div className="flex space-x-3">
              <Button>上传论文</Button>
              <Button variant="outline">浏览示例</Button>
            </div>
          </GlassCard>
          
          {/* 个人中心功能卡片 */}
          <GlassCard className="relative overflow-hidden group">
            <div className="absolute top-0 right-0 -mt-4 -mr-4 h-16 w-16 rounded-full bg-gradient-to-br from-[var(--theme-highlight)] to-[var(--theme-accent)] opacity-70 blur-xl group-hover:opacity-100 transition-opacity"></div>
            
            <h2 className="text-2xl font-bold text-white mb-3">个人中心</h2>
            <p className="text-white/80 mb-4">
              管理您的研究项目、收藏的论文和设置个人偏好，查看使用统计。
            </p>
            <div className="flex space-x-3">
              <a href="/profile" style={{ textDecoration: 'none' }}>
                <Button>进入中心</Button>
              </a>
              <a href="/profile?tab=settings" className="inline-block">
                <Button variant="outline">系统设置</Button>
              </a>
            </div>
          </GlassCard>
        </div>
        
        {/* 最近活动 */}
        <GlassCard className="w-full mb-6">
          <h2 className="text-xl font-bold text-white mb-4">最近活动</h2>
          <div className="space-y-3">
            <div className="flex items-center p-3 bg-white/5 rounded-lg">
              <div className="w-10 h-10 rounded-full bg-[var(--theme-accent)]/30 flex items-center justify-center mr-3">
                <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round" className="text-white">
                  <path d="M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1-2.5-2.5z"></path>
                  <path d="M8 7h6"></path>
                  <path d="M8 11h8"></path>
                  <path d="M8 15h5"></path>
                </svg>
              </div>
              <div className="flex-1">
                <h3 className="text-white font-medium">量子计算研究报告</h3>
                <p className="text-white/60 text-sm">3个研究方向，15篇相关论文</p>
              </div>
              <div className="text-white/50 text-sm">2小时前</div>
            </div>
            
            <div className="flex items-center p-3 bg-white/5 rounded-lg">
              <div className="w-10 h-10 rounded-full bg-[var(--theme-highlight)]/30 flex items-center justify-center mr-3">
                <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round" className="text-white">
                  <path d="M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z"></path>
                </svg>
              </div>
              <div className="flex-1">
                <h3 className="text-white font-medium">AI助手对话</h3>
                <p className="text-white/60 text-sm">关于机器学习模型评估的讨论</p>
              </div>
              <div className="text-white/50 text-sm">昨天</div>
            </div>
          </div>
        </GlassCard>
        
        <p className="text-white/50 text-center text-xs mt-8">
          基于人工智能的科研辅助系统 | 版本 1.0.0
        </p>
      </div>
    </main>
  );
} 