import type { Metadata } from "next";
import { Geist, Geist_Mono } from "next/font/google";
import Link from "next/link";
import "./globals.css";
import ClientInit from "@/components/ClientInit";

const geistSans = Geist({
  variable: "--font-geist-sans",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "文献启明星",
  description: "智能科研助手平台",
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="zh">
      <body
        className={`${geistSans.variable} ${geistMono.variable} antialiased theme-space`}
      >
        {/* 客户端初始化组件 */}
        <ClientInit />
        
        <div className="relative min-h-screen bg-gradient-to-br from-[var(--theme-bg-from)] via-[var(--theme-bg-via)] to-[var(--theme-bg-to)]">
          {/* 背景装饰 - 共享给所有页面 */}
          <div className="absolute inset-0 overflow-hidden pointer-events-none">
            <div className="stars absolute inset-0 z-0"></div>
            <div className="absolute top-1/4 left-1/3 w-[30rem] h-[30rem] bg-[var(--theme-accent)] rounded-full mix-blend-screen filter blur-[150px] opacity-20 animate-blob"></div>
            <div className="absolute top-1/3 right-1/4 w-[25rem] h-[25rem] bg-[var(--theme-highlight)] rounded-full mix-blend-screen filter blur-[120px] opacity-20 animate-blob animation-delay-2000"></div>
            <div className="absolute bottom-1/4 right-1/3 w-[20rem] h-[20rem] bg-white rounded-full mix-blend-screen filter blur-[100px] opacity-10 animate-blob animation-delay-4000"></div>
          </div>
          
          {/* 顶部导航栏 */}
          <header className="relative z-20">
            <nav className="container mx-auto px-4 py-4 flex items-center justify-between">
              <div className="flex items-center gap-2">
                <Link href="/" className="text-2xl font-bold text-white hover:opacity-90 transition-opacity flex items-center gap-2">
                  <span className="w-8 h-8 rounded-full bg-gradient-to-br from-[var(--theme-accent)] to-[var(--theme-highlight)] flex items-center justify-center">
                    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 24 24" fill="none" stroke="currentColor" strokeWidth="2" strokeLinecap="round" strokeLinejoin="round" className="text-white">
                      <polygon points="12 2 15.09 8.26 22 9.27 17 14.14 18.18 21.02 12 17.77 5.82 21.02 7 14.14 2 9.27 8.91 8.26 12 2"></polygon>
                    </svg>
                  </span>
                  <span>启明星</span>
                </Link>
              </div>
              
              <div className="flex items-center space-x-6">
                <NavLink href="/" label="文献研究" />
                <NavLink href="/ai-chat" label="AI聊天" />
                <NavLink href="/dashboard" label="控制台" />
                <NavLink href="/profile" label="个人中心" />
              </div>
            </nav>
          </header>
          
          {/* 页面内容 */}
          {children}
        </div>
      </body>
    </html>
  );
}

// 导航链接组件
function NavLink({ href, label }: { href: string; label: string }) {
  return (
    <Link 
      href={href} 
      className="text-white/80 hover:text-white transition-colors font-medium relative group"
    >
      {label}
      <span className="absolute bottom-0 left-0 w-0 h-0.5 bg-[var(--theme-accent)] group-hover:w-full transition-all duration-300"></span>
    </Link>
  );
}
