"use client";

import { useState, useEffect } from "react";
import { motion } from "framer-motion";

const themes = [
  { id: "space", name: "深邃宇宙", color: "#4D61FC" },
  { id: "ocean", name: "高级深海", color: "#26C5F3" },
  { id: "tech", name: "现代科技", color: "#FF2D72" },
  { id: "nightglow", name: "精致夜光", color: "#875EFF" },
];

export function ThemeSelector() {
  const [selectedTheme, setSelectedTheme] = useState("space");

  useEffect(() => {
    // 应用选中的主题到body元素
    const existingClasses = document.body.className.split(' ')
      .filter(cls => !cls.startsWith('theme-'));
    document.body.className = [...existingClasses, `theme-${selectedTheme}`].join(' ');
    
    // 添加本地存储，记住用户的主题选择
    localStorage.setItem('selectedTheme', selectedTheme);
  }, [selectedTheme]);
  
  // 从本地存储恢复用户主题
  useEffect(() => {
    const savedTheme = localStorage.getItem('selectedTheme');
    if (savedTheme) {
      setSelectedTheme(savedTheme);
    }
  }, []);

  return (
    <div className="absolute top-4 right-4 z-20">
      <div className="flex gap-2 backdrop-blur-md bg-white/10 p-2 rounded-full">
        {themes.map((theme) => (
          <button
            key={theme.id}
            onClick={() => setSelectedTheme(theme.id)}
            className={`w-6 h-6 rounded-full transition-all ${
              selectedTheme === theme.id
                ? "scale-110 shadow-lg"
                : "opacity-70"
            }`}
            style={{ backgroundColor: theme.color }}
            title={theme.name}
          />
        ))}
      </div>
    </div>
  );
}
