import { NextResponse } from 'next/server';
import type { NextRequest } from 'next/server';

// 需要保护的路径
const protectedPaths = [
  '/profile',
  '/research',
  // 可以添加更多需要保护的路径
];

// 不需要重定向的路径
const publicPaths = [
  '/login',
  '/register',
  '/api/',
  '/_next/',
  '/static/',
];

export function middleware(request: NextRequest) {
  // 获取路径
  const path = request.nextUrl.pathname;
  
  // 检查是否为公共路径
  if (publicPaths.some(publicPath => path.startsWith(publicPath))) {
    return NextResponse.next();
  }
  
  // 检查是否为保护路径
  if (protectedPaths.some(protectedPath => path.startsWith(protectedPath))) {
    // 检查是否有token（通过cookie）
    const token = request.cookies.get('token')?.value;
    
    if (!token) {
      // 没有token，重定向到登录页
      const loginUrl = new URL('/login', request.url);
      loginUrl.searchParams.set('redirect', path);
      return NextResponse.redirect(loginUrl);
    }
  }
  
  return NextResponse.next();
}

export const config = {
  matcher: [
    // 匹配所有路径，除了API路由和静态资源
    '/((?!api|_next/static|favicon.ico).*)',
  ],
}; 